act.plotting.SkewTDisplay
=========================

.. currentmodule:: act.plotting

.. autoclass:: SkewTDisplay

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~SkewTDisplay.__init__
      ~SkewTDisplay.add_colorbar
      ~SkewTDisplay.add_subplots
      ~SkewTDisplay.assign_to_figure_axis
      ~SkewTDisplay.plot_from_spd_and_dir
      ~SkewTDisplay.plot_from_u_and_v
      ~SkewTDisplay.put_display_in_subplot
      ~SkewTDisplay.set_xrng
      ~SkewTDisplay.set_yrng
   
   

   
   
   